@@ -1,6 +1,5 @@
 #!/bin/bash
-
-mversion=3.0
+mversion=4.0
 TTSENGINE=acapela
 
 echo "--- $TTSENGINE HTTP/TTS $mversion Installation ---"
@@ -14,6 +13,8 @@ perm_exec=775
 src=.
 dst=
 
+#part1
+#part2
 echo "Installing Web script..."
 wwwdirselect=/var/www
 echo $n "Enter apache web root directory[$wwwdirselect]: $c"
@@ -26,5 +27,8 @@ echo "Selected www dir : $wwwdirselect"
 mkdir -p $dst/$wwwdirselect/tts/$TTSENGINE
 install -m $perm_files $src/www/* $dst/$wwwdirselect/tts/$TTSENGINE
 
-echo "--- $TTSENGINE HTTP/TTS $mversion installation has finished ---"
+mkdir -p $dst/$wwwdirselect/tts/$TTSENGINE/html5media
+install -m $perm_files $src/html5media/* $dst/$wwwdirselect/tts/$TTSENGINE/html5media/
 
+
+echo "--- $TTSENGINE HTTP/TTS $mversion installation has finished ---"
